<?php
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2008 Bharat Mediratta
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * $Id: nls.php 193 2008-07-15 22:02:33Z jens $
 */

/**
 *
 * The basic idea and values was taken from then Horde Framework (http://horde.org)
 * The original filename was horde/config/nls.php.dist and it was
 * maintained by Jan Schneider (jan@horde.org)
 * The modifications to fit it for Gallery were made by Jens Tkotz
 *
 * @package	Language
 */

/* Defaults */
	$nls['language']['en_US']	=	'English (US)';

	$nls['postnuke']['en_US']	=	'eng';
	$nls['alias']['eng']		=	'en_US';

	$nls['phpnuke']['en_US']	=	'english';
	$nls['alias']['english']	=	'en_US';

	$nls['alias']['en']		=	'en_US';

/* Charset*/
	$nls['default']['charset']	= 	'ISO-8859-1';

/* Direction */
	$nls['default']['direction'] =	'ltr';
?>
